![logo](https://github.com/jlpl/aerosol-functions/raw/master/logo.png)

A collection of tools to analyze and visualize atmospheric aerosol and ion data.

## Installation
```shell
pip install aerosol-functions
```

## Documentation
See [here](https://jlpl.github.io/aerosol-functions/)
